@@ -1,8 +1,8 @@
 import json
 import secrets
+from xml.etree import ElementTree
 
 import aiohttp
-from lxml import html
 
 
 def danbooru():
@@ -28,8 +28,7 @@ def e621():
     client_data = {
         'as_json': True,
         'client_name': 'E621',
-        'client_url': 'https://e621.net/posts.json?tags=',
-        'headers': {'User-Agent': 'opalart/0.0.9'}
+        'client_url': 'https://e621.net/posts.json?tags='
     }
     return GalleryClient(client_data)
 
@@ -113,7 +112,7 @@ class GalleryClient(object):
         self.as_json = client_data.get('as_json')
         self.client_name = client_data.get('client_name')
         self.client_url = client_data.get('client_url')
-        self.headers = client_data.get('headers')
+        self.headers = {'User-Agent': 'opalart/0.1.0'}
         self.include_hash = False
         self.limit = None
         self.tags = None
@@ -134,7 +133,7 @@ class GalleryClient(object):
                     except json.JSONDecodeError:
                         posts = []
                 else:
-                    posts = html.fromstring(data)
+                    posts = ElementTree.fromstring(data)
         return self._filter_posts(posts)
 
     def _make_post_list(self, posts):
